<?php
/**
 * Voyage Theme Widgets
 *
 * @package Voyage
 * @subpackage Voyage
 * @since Voyage 1.0
 */
class Voyage_Recent_Post extends WP_Widget {
	function __construct() {
		WP_Widget::__construct(
			'widget_voyage_recent_post',
			__( '(Voyage) Recent Posts', 'voyage' ),
			array(
				'classname' => 'voyage_recent_post',
				'description' => __( 'Use this widget to list your recent post summary.', 'voyage' ),
			)
		);
	}
	// Widget outputs
	function widget( $args, $instance ) {
		extract( $args, EXTR_SKIP );
		$instance = wp_parse_args($instance, $this->widget_defaults());
		extract( $instance, EXTR_SKIP );
		$title = apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base);
					
 		if ( $random_post )
			$sortby = 'rand';
		else
			$sortby = '';
		if ( $sticky_post )
			$sticky = array();
		else
			$sticky = get_option( 'sticky_posts' );

		global $voyage_display_excerpt, $voyage_entry_meta;
		$voyage_display_excerpt = $display_excerpt;
		$voyage_entry_meta = $entry_meta;
						
		$query_str = array(
			'order' => 'DESC',
			'orderby' => $sortby,
			'posts_per_page' => $number,
			'post_status' => 'publish',
			'post_type' => 'post',
			'category__in'   => $category,
			'post__not_in' => $sticky,
			'ignore_sticky_posts' => 1,
			'no_found_rows' => 1,
		);

		$recent_posts = new WP_Query( $query_str );

		if ( $recent_posts->have_posts() ) :
			echo $before_widget; 
			echo '<div class="clear"></div>';
			if ( ! empty( $title ) ) {
				echo $before_title;
				echo $title; // Can set this with a widget option, or omit altogether
				echo $after_title;			
				if ( ! empty( $category_link ) && $category ) {
			
					printf( '<a href="%1$s" title="%2$s" class="voyage_recent_post_link btn btn-small btn-transparent">%3$s</a>',
						get_category_link( $category ) ,
						get_the_category_by_ID( $category ),
						$category_link );					
				}	
			}

			global $voyage_thumbnail;
			
			$voyage_thumbnail = voyage_thumbnail_size( $thumbnail, $thumbnail_x, $thumbnail_y);

			$col = 0;
			while ( $recent_posts->have_posts() ) : 
				$recent_posts->the_post();
				$div_class = '';

				if ($column == 2) {
					$div_class = "one_half ";
					if ($col == 0)
						$div_class .= "alpha";
					else
						$div_class .= "omega";
					$col = $col + 1;
					if ($col == 2)
						$col = 0;
				}
				elseif ($column == 3) {
					$div_class = "one_third ";
					if ($col == 0)
						$div_class .= "alpha";
					elseif ($col == 2)
						$div_class .= "omega";
					$col = $col + 1;
					if ($col == 3)
						$col = 0;
				}
				elseif ($column == 4) {
					$div_class = "one_quarter ";
					if ($col == 0)
						$div_class .= "alpha";
					elseif ($col == 3)
						$div_class .= "omega";
					$col = $col + 1;
					if ($col == 4)
						$col = 0;
				}

				if  ($column > 1)
					echo '<div class="' . $div_class .'">';
				get_template_part( 'content', 'summary' );
				
				if  ($column > 1) {
					echo '</div>';				
					if ($col == 0)
						echo '<div class="clear"></div>';
				}
			endwhile;
			
			if ($col > 0)
				echo '<div class="clear"></div>';
			echo $after_widget;
			// Reset the post globals as this query will have stomped on it
			wp_reset_postdata();
		endif;
	}

	// Update options
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['number'] = (int) $new_instance['number'];
		$col = (int) $new_instance['column'];
		if ($col > 4)
			$col = 4;
		if ($col <1 )
			$col = 1;
		$instance['column'] = $col;
		$instance['category'] =  (int) $new_instance['category'];
		$instance['sticky_post'] =  (int) $new_instance['sticky_post'];
		$instance['random_post'] =  (int) $new_instance['random_post'];
		$instance['entry_meta'] =  (int) $new_instance['entry_meta'];
		$instance['category_link'] =  strip_tags($new_instance['category_link']);
		$instance['display_excerpt'] =  $new_instance['display_excerpt'];
		$instance['thumbnail'] = $new_instance['thumbnail'];
		$size = (int) $new_instance['thumbnail_x'];
		if ($size < 1)
			$size = 64;
		$instance['thumbnail_x'] = $size;
		$size = (int) $new_instance['thumbnail_y'];
		if ($size < 1)
			$size = 64;
		$instance['thumbnail_y'] = $size;

		return $instance;
	}
	
	function widget_defaults() {
		return array(
			'title' => '',
			'number' => '10',
			'category' => '0',
			'sticky_post' => '0',
			'random_post' => '0',
			'column' => '1',
			'thumbnail' => '1',
			'thumbnail_x' => '64',
			'thumbnail_y' => '64',
			'display_excerpt' => 1,
			'entry_meta' => '0',
			'category_link' => '',
		);
	}
	// Display options
	function form( $instance ) {
		$instance = wp_parse_args($instance, $this->widget_defaults());
?>
		<p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Title:', 'voyage' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" /></p>

		<p><label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php _e( 'Number of posts to show:', 'voyage' ); ?></label>
		<input id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['number'] ); ?>" size="3" /></p>
		
		<p><input id="<?php echo esc_attr( $this->get_field_name( 'random_post' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'random_post' ) ); ?>" type="checkbox" value="1" <?php checked( '1', $instance['random_post'] ); ?> />
		<label for="<?php echo esc_attr( $this->get_field_id( 'random_post' ) ); ?>"><?php _e( 'Random Posts', 'voyage' ); ?></label></p>
		
		<p><label for="<?php echo esc_attr( $this->get_field_id( 'column' ) ); ?>"><?php _e( 'No of Columns (1-4):', 'voyage' ); ?></label>
		<input id="<?php echo esc_attr( $this->get_field_id( 'column' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'column' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['column'] ); ?>" size="3" /></p>
		
		<label for="<?php echo esc_attr( $this->get_field_id( 'category' ) ); ?>"><?php _e( 'Category:', 'voyage' ); ?></label>
		<select name="<?php echo esc_attr( $this->get_field_name( 'category' ) ); ?>" id="<?php echo esc_attr( $this->get_field_name( 'category' ) ); ?>">
		
		<?php if ( $instance['category'] == '0' )
				$selected = 'selected="selected"';
			  else 
			  	$selected = ''; ?>
				
			<option value="<?php echo "0"; ?>" <?php echo $selected; ?>><?php _e('All Categories','voyage'); ?></option>
		<?php
			foreach ( voyage_categories() as $option ) {
				if ( $instance['category'] == $option->term_id )
					$selected = 'selected="selected"';
				else
					$selected = '';
?>
				<option value="<?php echo $option->term_id; ?>" <?php echo $selected; ?>><?php echo $option->name; ?></option>
		<?php } ?>
		</select>
		
		<p><input id="<?php echo esc_attr( $this->get_field_name( 'sticky_post' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'sticky_post' ) ); ?>" type="checkbox" value="1" <?php checked( '1', $instance['sticky_post'] ); ?> />
		<label for="<?php echo esc_attr( $this->get_field_id( 'sticky_post' ) ); ?>"><?php _e( 'include sticky posts in the category', 'voyage' ); ?></label></p>

		<p><label><b><?php _e('Thumbnail: ','voyage'); ?></b></label>
		<input id="<?php echo esc_attr( $this->get_field_name( 'thumbnail' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'thumbnail' ) ); ?>" type="radio" value="1" <?php checked( '1', $instance['thumbnail'] ); ?> /><?php _e( 'Thumbnail', 'voyage' ); ?>
		<input id="<?php echo esc_attr( $this->get_field_name( 'thumbnail' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'thumbnail' ) ); ?>" type="radio" value="2" <?php checked( '2', $instance['thumbnail'] ); ?> /><?php _e( 'Medium<br>', 'voyage' ); ?>
		<input id="<?php echo esc_attr( $this->get_field_name( 'thumbnail' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'thumbnail' ) ); ?>" type="radio" value="3" <?php checked( '3', $instance['thumbnail'] ); ?> /><?php _e( 'Large', 'voyage' ); ?>
		<input id="<?php echo esc_attr( $this->get_field_name( 'thumbnail' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'thumbnail' ) ); ?>" type="radio" value="4" <?php checked( '4', $instance['thumbnail'] ); ?> /><?php _e( 'Full', 'voyage' ); ?>
		<input id="<?php echo esc_attr( $this->get_field_name( 'thumbnail' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'thumbnail' ) ); ?>" type="radio" value="5" <?php checked( '5', $instance['thumbnail'] ); ?> /><?php _e( 'Custom', 'voyage' ); ?>
		<input id="<?php echo esc_attr( $this->get_field_name( 'thumbnail' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'thumbnail' ) ); ?>" type="radio" value="6" <?php checked( '6', $instance['thumbnail'] ); ?> /><?php _e( 'None', 'voyage' ); ?></p>

		<p><label><?php _e( 'Custom size: ', 'voyage' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'thumbnail_x' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'thumbnail_x' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['thumbnail_x'] ); ?>" size="3" /><label><?php _e( ' x ', 'voyage' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'thumbnail_y' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'thumbnail_y' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['thumbnail_y'] ); ?>" size="3" /></p>

		<p><label><b><?php _e('Intro Text: ','voyage'); ?></b></label>
		<input id="<?php echo esc_attr( $this->get_field_name( 'display_excerpt' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'display_excerpt' ) ); ?>" type="radio" value="1" <?php checked( '1', $instance['display_excerpt'] ); ?> /><?php _e( 'Excerpt', 'voyage' ); ?>
		<input id="<?php echo esc_attr( $this->get_field_name( 'display_excerpt' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'display_excerpt' ) ); ?>" type="radio" value="2" <?php checked( '2', $instance['display_excerpt'] ); ?> /><?php _e( 'Content', 'voyage' ); ?>
		<input id="<?php echo esc_attr( $this->get_field_name( 'display_excerpt' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'display_excerpt' ) ); ?>" type="radio" value="3" <?php checked( '3', $instance['display_excerpt'] ); ?> /><?php _e( 'None', 'voyage' ); ?></p>

		<p><input id="<?php echo esc_attr( $this->get_field_name( 'entry_meta' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'entry_meta' ) ); ?>" type="checkbox" value="1" <?php checked( '1', $instance['entry_meta'] ); ?> />
		<label for="<?php echo esc_attr( $this->get_field_id( 'entry_meta' ) ); ?>"><?php _e( 'Display post meta', 'voyage' ); ?></label></p>

		<p><label for="<?php echo esc_attr( $this->get_field_id( 'category_link' ) ); ?>"><b><?php _e( 'Category Link : ', 'voyage' ); ?></b></label><input id="<?php echo esc_attr( $this->get_field_name( 'category_link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'category_link' ) ); ?>" type="text" value="<?php echo esc_attr($instance['category_link']); ?>" />
		</p>
		<?php
	}
}

class Voyage_Navigation extends WP_Widget {
	function __construct() {
		WP_Widget::__construct(
			'widget_voyage_navigation',
			__( '(Voyage) Navigation Tabs', 'voyage' ),
			array(
				'classname'   => 'voyage_navigation',
				'description' => __( 'Tabbed navigation.', 'voyage' ),
			)
		);
	}
	// Widget outputs
	function widget( $args, $instance ) {
		extract( $args, EXTR_SKIP );
		$instance = wp_parse_args($instance, $this->widget_defaults());
		extract( $instance, EXTR_SKIP );
		$title = apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base);		
		$id = substr($widget_id,25);

		$tabs = array();
		if ($category)
			$tabs[] = array( 'order' => $category,
							 'type'	 => 'category',
							 'name' =>  $category_label );
		if ($archive)
			$tabs[] = array( 'order' => $archive,
							 'type'	 => 'archive',
							 'name' =>  $archive_label );
		if ($recent)
			$tabs[] = array( 'order' => $recent,
							 'type'	 => 'recent',
							 'name' =>  $recent_label );
		if ($tag)
			$tabs[] = array( 'order' => $tag,
							 'type'	 => 'tag',
							 'name' =>  $tag_label );
		if ($menu && $menu_id)
			$tabs[] = array( 'order' => $menu,
							 'type'	 => 'menu',
							 'name' =>  $menu_label );

		voyage_sort_array($tabs, "order");

		echo $before_widget; 

		if (!empty($title) ) {
			echo $before_title;
			echo $title;
			echo $after_title;
		} 

        echo '<ul id="vntTab" class="nav nav-tabs">';
		$active = ' class="active"';
		foreach ($tabs as $tab) {
			if ($tab['order'] > 0) {
				echo '<li' . $active . '><a href="#';
				echo $tab['type'] . $id .'" data-toggle="tab">';
				echo $tab['name'] . '</a></li>';
				$active = '';
			}
		}	
		echo '</ul>';
		echo '<div id="vntTabContent" class="tab-content">';
		$active = " in active";
		foreach ($tabs as $tab) {
		  if ($tab['order'] > 0) {
			switch ($tab['type']) {
			  case 'category':
				echo '<div class="widget_categories tab-pane fade' . $active;
				echo '" id="' . $tab['type'] . $id . '">';
				echo '<ul>';
				
				$cat_args = array();
				$cat_args['show_count'] = $showcount;
				$cat_args['title_li'] = '';
				$cat_args['exclude'] = 1;
				wp_list_categories( $cat_args );	
							
				echo '</ul></div>';		
				break;
			  case 'archive':
				echo '<div class="widget_archive tab-pane fade' . $active;
				echo '" id="' . $tab['type'] . $id . '">';
				echo '<ul>';
				
				$arc_args = array();
				$arc_args['type'] = 'monthly';
				$arc_args['show_post_count'] = $showcount;	
				$arc_args['limit'] = $limits;
				wp_get_archives( $arc_args ); 	
							
				echo '</ul></div>';		
				break;
			  case 'recent':
				echo '<div class="widget_recent_entries tab-pane fade' . $active;
				echo '" id="' . $tab['type'] . $id . '">';
				echo '<ul>';
				
				$rec_args = array();
				$rec_args['numberposts'] = $limits;
				$rec_args['post_status'] = 'publish';
				$recent_posts = wp_get_recent_posts( $rec_args ); 
				foreach( $recent_posts as $recent_post ){
					echo '<li><a href="' . get_permalink($recent_post["ID"]) . '" title="Look '.esc_attr($recent_post["post_title"]).'" >' . $recent_post["post_title"].'</a> </li> ';
				}			
				echo '</ul></div>';		
				break;
			  case 'tag':
				echo '<div class="widget_tag_cloud tab-pane fade' . $active;
				echo '" id="' . $tab['type'] . $id . '">';
				echo '<ul>';
				
				$tag_args = array();
				wp_tag_cloud( $tag_args ); 			
				echo '</ul></div>';		
				break;
			  case 'menu':
				echo '<div class="widget_nav_menu tab-pane fade' . $active;
				echo '" id="' . $tab['type'] . $id . '">';
				
				$menu_args = array();
				$menu_args['menu'] = $menu_id;
				wp_nav_menu( $menu_args);		
				echo '</div>';		
				break;
			}
			$active = '';
		  }
		}		
        echo '</div>';

		echo $after_widget;
		// Reset the post globals as this query will have stomped on it
		wp_reset_postdata();
	}

	// Update options
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['category'] =  (int) $new_instance['category'];
		$instance['archive'] =  (int) $new_instance['archive'];
		$instance['recent'] =  (int) $new_instance['recent'];
		$instance['tag'] =  (int) $new_instance['tag'];
		$instance['menu'] =  (int) $new_instance['menu'];		
		$instance['showcount'] =  (int) $new_instance['showcount'];
		$instance['limits'] =  (int) $new_instance['limits'];		

		$instance['category_label'] =  wp_kses_stripslashes($new_instance['category_label']);
		$instance['archive_label'] =  wp_kses_stripslashes($new_instance['archive_label']);
		$instance['recent_label'] =  wp_kses_stripslashes($new_instance['recent_label']);
		$instance['tag_label'] =  wp_kses_stripslashes($new_instance['tag_label']);
		$instance['menu_label'] =  wp_kses_stripslashes($new_instance['menu_label']);
		$instance['menu_id'] =  $new_instance['menu_id'];			
		return $instance;
	}

	function widget_defaults() {
		return array(
			'title' => '',
			'category' => '1',
			'category_label' => __('Categories','voyage'),
			'archive' => '2',
			'archive_label' => __('Archives','voyage'),
			'recent' => '0',
			'recent_label' => __('Latest','voyage'),
			'tag' => '3',
			'tag_label' => __('Tags','voyage'),
			'menu' => '0',
			'menu_label' => __('Menu','voyage'),
			'menu_id' => '0',
			'showcount' => '1',
			'limits' => '10',
		);
	}

	// Display options
	function form( $instance ) {
		$instance = wp_parse_args( $instance, $this->widget_defaults() );
		?>
		<p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Title:', 'voyage' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" /></p>
		<p><strong>Tab Name</strong> / Order / Label</p>
		
		<p><label for="<?php echo esc_attr( $this->get_field_id( 'category' ) ); ?>"><?php _e( 'Categories', 'voyage' ); ?></label>&nbsp;/&nbsp;
		<input id="<?php echo esc_attr( $this->get_field_name( 'category' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'category' ) ); ?>" type="text" size="1" value="<?php echo esc_attr($instance['category']); ?>" />&nbsp;/&nbsp;
		<input id="<?php echo esc_attr( $this->get_field_name( 'category_label' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'category_label' ) ); ?>" type="text" size="10" value="<?php echo esc_attr($instance['category_label']); ?>" /></p>

		<p><label for="<?php echo esc_attr( $this->get_field_id( 'archive' ) ); ?>"><?php _e( 'Archives', 'voyage' ); ?></label>&nbsp;/&nbsp;
		<input id="<?php echo esc_attr( $this->get_field_name( 'archive' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'archive' ) ); ?>" type="text" size="1" value="<?php echo esc_attr($instance['archive']); ?>" />&nbsp;/&nbsp;
		<input id="<?php echo esc_attr( $this->get_field_name( 'archive_label' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'archive_label' ) ); ?>" type="text" size="10" value="<?php echo esc_attr($instance['archive_label']); ?>" /></p>

		<p><label for="<?php echo esc_attr( $this->get_field_id( 'recent' ) ); ?>"><?php _e( 'Recent Posts', 'voyage' ); ?></label>
		<input id="<?php echo esc_attr( $this->get_field_name( 'recent' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'recent' ) ); ?>" type="text" size="1" value="<?php echo esc_attr($instance['recent']); ?>" />&nbsp;/&nbsp;
		<input id="<?php echo esc_attr( $this->get_field_name( 'recent_label' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'recent_label' ) ); ?>" type="text" size="10" value="<?php echo esc_attr($instance['recent_label']); ?>" /></p>

		<p><label for="<?php echo esc_attr( $this->get_field_id( 'tag' ) ); ?>"><?php _e( 'Tags', 'voyage' ); ?></label>&nbsp;/&nbsp;
		<input id="<?php echo esc_attr( $this->get_field_name( 'tag' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'tag' ) ); ?>" type="text" size="1" value="<?php echo esc_attr($instance['tag']) ; ?>" />&nbsp;/&nbsp;
		<input id="<?php echo esc_attr( $this->get_field_name( 'tag_label' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'tag_label' ) ); ?>" type="text" size="10" value="<?php echo esc_attr($instance['tag_label']) ; ?>" /></p>
		
		<p><label for="<?php echo esc_attr( $this->get_field_id( 'menu' ) ); ?>"><?php _e( 'Menu', 'voyage' ); ?></label>&nbsp;/&nbsp;
		<input id="<?php echo esc_attr( $this->get_field_name( 'menu' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'menu' ) ); ?>" type="text" size="1" value="<?php echo esc_attr($instance['menu']) ; ?>" />&nbsp;/&nbsp;
		<input id="<?php echo esc_attr( $this->get_field_name( 'menu_label' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'menu_label' ) ); ?>" type="text" size="10" value="<?php echo esc_attr($instance['menu_label']) ; ?>" /></p>
		
		<p><input id="<?php echo esc_attr( $this->get_field_name( 'showcount' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'showcount' ) ); ?>" type="checkbox" value="1" <?php checked( '1', $instance['showcount'] ); ?> />
		<label for="<?php echo esc_attr( $this->get_field_id( 'showcount' ) ); ?>"><?php _e( 'Show Post Counts', 'voyage' ); ?></label></p>

		<p><label for="<?php echo esc_attr( $this->get_field_id( 'limits' ) ); ?>"><?php _e( 'Post/Line Limits', 'voyage' ); ?></label>
		<input id="<?php echo esc_attr( $this->get_field_name( 'limits' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'limits' ) ); ?>" type="text" size="2" value="<?php echo esc_attr($instance['limits']); ?>" /></p>

		<label for="<?php echo esc_attr( $this->get_field_id( 'menu_id' ) ); ?>"><?php _e( 'Menu:', 'voyage' ); ?></label>
		<select name="<?php echo esc_attr( $this->get_field_name( 'menu_id' ) ); ?>" id="<?php echo esc_attr( $this->get_field_name( 'menu_id' ) ); ?>">
		<?php if ( $menu_id == '0' )
				$selected = 'selected="selected"';
			  else 
			  	$selected = ''; ?>
				
			<option value="<?php echo "0"; ?>" <?php echo $selected; ?>><?php _e('Select Menu','voyage'); ?></option>
		<?php
			foreach ( get_terms('nav_menu') as $menu ) {
				if ( $instance['menu_id'] == $menu->term_id )
					$selected = 'selected="selected"';
				else
					$selected = ''; ?>
				<option value="<?php echo $menu->term_id; ?>" <?php echo $selected; ?>><?php echo $menu->name; ?></option>
		<?php } ?>
		</select>	
		<?php
	}
}
